@@ -171,36 +171,78 @@ class User(MojoSecrets, AbstractBaseUser, MojoModel):
         if req:
             req.device = UserDevice.track(request=req, user=self)
 
-    def get_groups(self, is_active=True):
+    def get_groups(self, is_active=True, include_children=True):
         """
         Returns a QuerySet of all groups the user is a member of.
 
         Args:
             is_active: Filter by active members (default True). Set to None to get all.
+            include_children: Include child groups down the parent chain (default True).
+                             Set to False to get only direct memberships.
 
         Returns:
             QuerySet of Group objects
         """
         from mojo.apps.account.models import Group
+
+        # Get direct groups the user is a member of
         queryset = Group.objects.filter(members__user=self)
         if is_active is not None:
             queryset = queryset.filter(members__is_active=is_active)
+
+        # If not including children, return direct memberships only
+        if not include_children:
+            return queryset.distinct()
+
+        # Collect all group IDs including children
+        direct_groups = queryset
+        all_group_ids = set()
+        for group in direct_groups:
+            all_group_ids.add(group.id)
+            # Add all child group IDs
+            child_ids = group._get_all_child_ids()
+            all_group_ids.update(child_ids)
+
+        # Return queryset with all groups
+        queryset = Group.objects.filter(id__in=all_group_ids)
+        if is_active is not None:
+            queryset = queryset.filter(is_active=is_active)
+
         return queryset.distinct()
 
-    def get_group_ids(self, is_active=True):
+    def get_group_ids(self, is_active=True, include_children=True):
         """
         Returns a list of group IDs the user is a member of.
 
         Args:
             is_active: Filter by active members (default True). Set to None to get all.
+            include_children: Include child groups down the parent chain (default True).
+                             Set to False to get only direct memberships.
 
         Returns:
             List of group IDs
         """
+        from mojo.apps.account.models import Group
+
+        # Get direct group memberships
         queryset = self.members.all()
         if is_active is not None:
             queryset = queryset.filter(is_active=is_active)
-        return list(queryset.values_list('group_id', flat=True))
+        direct_group_ids = list(queryset.values_list('group_id', flat=True))
+
+        # If not including children, return direct memberships only
+        if not include_children:
+            return direct_group_ids
+
+        # Collect all group IDs including children
+        all_group_ids = set(direct_group_ids)
+        direct_groups = Group.objects.filter(id__in=direct_group_ids)
+        for group in direct_groups:
+            # Add all child group IDs
+            child_ids = group._get_all_child_ids()
+            all_group_ids.update(child_ids)
+
+        return list(all_group_ids)
 
     def get_groups_with_permission(self, perms, is_active=True):
         """
@@ -518,11 +560,15 @@ class User(MojoSecrets, AbstractBaseUser, MojoModel):
     def send_invite(self, **kwargs):
         from mojo.apps.account.utils import tokens
 
-        context = kwargs.copy()
-        context.update({
+        context = {
             "user": self.to_dict("basic"),
             "token": tokens.generate_token(self)
-        })
+        }
+        for key, value in kwargs.items():
+            if hasattr(value, 'to_dict'):
+                context[key] = value.to_dict('basic')
+            elif isinstance(value, (str, int, float)):
+                context[key] = value
 
         self.send_template_email(
             template_name="invite",
@@ -596,6 +642,7 @@ class User(MojoSecrets, AbstractBaseUser, MojoModel):
         cc=None,
         bcc=None,
         reply_to=None,
+        template_prefix=None,
         **kwargs
     ):
         """Send template email to this user using mailbox determined by user's org domain or system default
@@ -612,7 +659,7 @@ class User(MojoSecrets, AbstractBaseUser, MojoModel):
         Raises:
             ValueError: If no mailbox can be found or template not found
         """
-        from mojo.apps.aws.models import Mailbox
+        from mojo.apps.aws.models import Mailbox, EmailTemplate
 
         mailbox = None
 
@@ -636,6 +683,13 @@ class User(MojoSecrets, AbstractBaseUser, MojoModel):
         if not mailbox:
             raise ValueError("No mailbox available for sending email. Please configure a system default mailbox.")
 
+        if template_prefix is None and self.org:
+            template_prefix = self.org.get_metadata_value("email_template")
+        if template_prefix:
+            new_template_name = f"{template_prefix}_{template_name}"
+            if EmailTemplate.objects.filter(name=new_template_name).exists():
+                template_name = new_template_name
+
         # Add user to context if not already present
         if context is None:
             context = {}
